# MST-AUGer

Synthetic mixture-based data augmentation for microbial source tracking

## Installation

MST-AUGer is available as in official Python Package index (PyPI). To install MST-AUGer, run the following command in your terminal.

```bash
pip install mst-auger
```

If you're in China, you can also install from mirror site (synchronized from official PyPI by Tsinghua University).

```bash
pip install mst-auger -i https://pypi.tuna.tsinghua.edu.cn/simple
```

## Documentation

For full documentation visit [mst-auger.rtfd.io](http://mst-auger.rtfd.io/)

## Author

Hui Chong: huichong.me@gmail.com